@@ -29,6 +29,7 @@
 //#include <gtkmm/tooltip.h>
 
 #include "mrview/slice.h"
+#include <deque>
 
 namespace MR {
   namespace Viewer {
@@ -43,15 +44,74 @@ namespace MR {
           virtual ~DP_ROIList();
 
           void draw (int transparency);
-          bool on_button_press (GdkEventButton* event, float brush);
-          bool on_motion (GdkEventMotion* event, float brush) { if (editing) { process (event->x, event->y, brush); return (true); } return (false); };
-          bool on_button_release (GdkEventButton* event) { if (editing) { editing = false; return (true); } return (false); }
+	  bool on_button_press (GdkEventButton* event, float brush, bool brush3d, bool isobrush);
+  	  bool on_motion (GdkEventMotion* event, float brush, bool brush3d, bool isobrush) 
+	  { 
+	    if (editing) 
+	      { 
+	      process (event->x, event->y, brush, brush3d, isobrush);
+	      return (true); 
+	      } 
+	    return (false); 
+	  };
+
+          bool on_button_release (GdkEventButton* event) 
+	  { 
+	    if (editing) 
+	      { 
+	      editing = false;
+	      // push undo buffer onto queue, then clear it
+	      AddToUndo(processUndoBuff);
+	      processUndoBuff.clear();
+	      return (true); 
+	      } 
+	    return (false); 
+	  }
+
+	  bool on_key_press (GdkEventKey* event);
+
+          bool undo();
+          bool redo();
+          bool floodfill();
+	  bool copyslice(gint offset);
 
         protected:
           const ROIAnalysis& parent;
           bool  set, editing;
           Gtk::TreeModel::Row row;
 
+	  // not the most efficient way of doing this, but will do for starters.
+	  unsigned MaxUndoSize;
+          class EdVox {
+            public:
+              EdVox (bool value, gsize offset) : value (value), offset (offset) { }
+              bool value;
+              gsize offset;
+          };
+
+          typedef std::vector<EdVox> EdVecType;
+          typedef std::deque< EdVecType > EditQueueType;
+
+          // undo/redo queues
+          EditQueueType UndoQueue, RedoQueue;
+	  // a global undo buffer so we don't need to change the 
+          // mouse buttonpress interface
+	  EdVecType processUndoBuff;
+	  // applies the undo, and modifies EV to become a suitable redo list.
+	  void ApplyUndo(EdVecType &EV);
+	  void AddToUndo(EdVecType EV);
+
+          void AddVox(MR::Image::Position ima, EdVecType &EV) { EV.push_back (EdVox (ima.value(), ima.getoffset())); }
+
+          void AddVox(MR::Image::Position ima, EdVecType &EV, const float value)
+          {
+            float val = ima.value();
+              // only push if it has changed.
+              // specifically for drawing
+            if (val != value) 
+              EV.push_back (EdVox (val, ima.getoffset()));
+          }
+
           class ROI {
             public:
               ROI (RefPtr<MR::Image::Object> image, guint32 C) : mask (new Image (image)), render (false), colour (C) { mask->image->set_read_only (false);}
@@ -82,7 +142,9 @@ namespace MR {
           void on_clear ();
           void on_tick (const String& path);
 
-          void process (gdouble x, gdouble y, float brush);
+          bool set_selected_row ();
+
+	  void process (gdouble x, gdouble y, float brush, bool brush3d, bool isobrush);
           Point position (gdouble x, gdouble y);
 
           void load (RefPtr<MR::Image::Object> image);
