@@ -5,15 +5,16 @@ exe_suffix = ''
 lib_prefix = 'lib'
 lib_suffix = '.dylib'
 
-cpp = [ 'g++', '-c', '$flags$', '$gtk$', '$path$', '$src$', '-o', '$obj$' ]
-cpp_flags = [ '-Wall', '-mtune=native', '-fPIC', '-fno-strict-aliasing', '-DGL_GLEXT_PROTOTYPES', '-DUSE_TR1' ]
+cpp = [ 'clang++', '-c', '$flags$', '$gtk$', '$path$', '$src$', '-o', '$obj$' ]
+cpp_flags = [ '-Wall', '-mtune=native', '-fPIC', '-fno-strict-aliasing', '-DGL_GLEXT_PROTOTYPES' ]
 
-ld = [ 'g++', '$flags$', '$path$', '$obj$', '$mrtrix$', '$gsl$', '$gtk$', '$lz$', '-o', '$bin$' ]
-ld_flags = []
+ld_use_shell = True
+ld = [ 'clang++', '$flags$', '$path$', '$obj$', '$mrtrix$', '$gsl$', '$gtk$', '$lz$', '-o', '$bin$' ]
+ld_flags = [ '-Wl,-rpath,@loader_path/../lib ']
 ld_flags_lib_prefix = '-l'
 
-ld_lib = [ 'g++', '-shared', '$flags$', '$obj$', '-o', '$lib$' ]
-ld_lib_flags = []
+ld_lib = [ 'clang++', '-shared', '$flags$', '$obj$', '-o', '$lib$' ]
+ld_lib_flags = [ '-dynamiclib', '-install_name', '@rpath/LIBNAME' ]
 
 # look for MacPorts or FINK dependencies, and act accordingly if found:
 dep_dir = [ '/opt/local', '/sw64', '/sw' ]
@@ -32,6 +33,7 @@ cpp_flags_profile = [ '-pg' ] + cpp_flags_debug
 ld_flags_profile = ld_flags_debug + [ '-pg' ]
 ld_lib_flags_profile = ld_lib_flags_debug + [ '-pg' ]
 
+
 cpp_flags += [ '-O2' ]
 
 cpp_flags_release = [ '-DNDEBUG' ]
